@@ -19,11 +19,12 @@ _HELP_MESSAGE_REUSE = """
 
         Options:
             -h\t\t\t    Print help message
+            -v\t\t\t    Print FOSSLight Prechecker version
             -p <path>\t\t    Path to check
             -f <format>\t\t    Result format(yaml, xml, html)
             -o <file_name>\t    Output file name
             -n\t\t\t    Don't exclude venv*, node_modules, and .*/ from the analysis
-            -i\t\t\t    Don't write log to file
+            -i\t\t\t    Don't both write log file and show progress bar
 
         Options for only 'add' mode
             -l <license>\t    License name(SPDX format) to add
